#############################################################################
### Script file to produce some figures of quantities of interest across Swiss cantons for the project with Cody and Christopher
###
### Created: 8-22-17
### Modified:
###
#############################################################################

library(maptools)
library(ggplot2)
library(sp)
library(foreign)
library(grid)
library(gridExtra)

setwd("C:/Users/williamslaro/Documents/Research/Projects/Spatial Methods/Diffusion/")

### Load the Swiss cantons data
swiss = read.dta("Survey/Replication/Gilardi-Wasserfallen-BJPS-2016-replication -- TLSL/Figures/Swiss Cantons.dta", convert.underscore=TRUE)

### Best version (label Bern)
pdf(file="Manuscript/t1_tp0.pdf", family="Times")
t1.0 <- ggplot() + 
	geom_polygon(data=swiss, aes(x=.X, y=.Y, group = .ID, fill = slte.theta1.tp0), color="white") +
	geom_text(aes(x = 7.8, y = 46.7, label = "Berne"), color = "red", size = 12) +
	xlab("") + ylab("") + theme(panel.background = element_blank(), axis.ticks = element_blank(), axis.text.x = element_blank(), axis.text.y = element_blank(), legend.position = "none") +
	scale_fill_gradient(low = "gray90", high = "gray10") 
t1.0
dev.off()

pdf(file="Manuscript/t1_tp1.pdf", family="Times")
t1.1 <- ggplot() + 
	geom_polygon(data=swiss, aes(x=.X, y=.Y, group = .ID, fill = slte.theta1.tp1), color="white") +
	geom_text(aes(x = 7.8, y = 46.7, label = "Berne"), color = "red", size = 12) +
	xlab("") + ylab("") + theme(panel.background = element_blank(), axis.ticks = element_blank(), axis.text.x = element_blank(), axis.text.y = element_blank(), legend.position = "none") +
	scale_fill_gradient(low = "gray90", high = "gray10") 
t1.1
dev.off()

pdf(file="Manuscript/t1_tp2.pdf", family="Times")
t1.2 <- ggplot() + 
	geom_polygon(data=swiss, aes(x=.X, y=.Y, group = .ID, fill = slte.theta1.tp2), color="white") +
	geom_text(aes(x = 7.8, y = 46.7, label = "Berne"), color = "red", size = 12) +
	xlab("") + ylab("") + theme(panel.background = element_blank(), axis.ticks = element_blank(), axis.text.x = element_blank(), axis.text.y = element_blank(), legend.position = "none") +
	scale_fill_gradient(low = "gray90", high = "gray10") 
t1.2
dev.off()

pdf(file="Manuscript/t1_tp3.pdf", family="Times")
t1.3 <- ggplot() + 
	geom_polygon(data=swiss, aes(x=.X, y=.Y, group = .ID, fill = slte.theta1.tp3), color="white") +
	geom_text(aes(x = 7.8, y = 46.7, label = "Berne"), color = "red", size = 12) +
	xlab("") + ylab("") + theme(panel.background = element_blank(), axis.ticks = element_blank(), axis.text.x = element_blank(), axis.text.y = element_blank(), legend.position = "none") +
	scale_fill_gradient(low = "gray90", high = "gray10") 
t1.3
dev.off()

t2.0 <- ggplot() + 
	geom_polygon(data=swiss, aes(x=.X, y=.Y, group = .ID, fill = slte.theta2.tp0), color="white") +
	geom_text(aes(x = 7.6, y = 46.9, label = "Berne"), color = "red") +
	xlab("") + ylab("") + theme(panel.background = element_blank(), axis.ticks = element_blank(), axis.text.x = element_blank(), axis.text.y = element_blank(), legend.position = "none") +
	scale_fill_gradient(low = "gray90", high = "gray10") 
t2.0

t2.1 <- ggplot() + 
	geom_polygon(data=swiss, aes(x=.X, y=.Y, group = .ID, fill = slte.theta2.tp1), color="white") +
	geom_text(aes(x = 7.6, y = 46.9, label = "Berne"), color = "red") +
	xlab("") + ylab("") + theme(panel.background = element_blank(), axis.ticks = element_blank(), axis.text.x = element_blank(), axis.text.y = element_blank(), legend.position = "none") +
	scale_fill_gradient(low = "gray90", high = "gray10") 
t2.1

t2.2 <- ggplot() + 
	geom_polygon(data=swiss, aes(x=.X, y=.Y, group = .ID, fill = slte.theta2.tp2), color="white") +
	geom_text(aes(x = 7.6, y = 46.9, label = "Berne"), color = "red") +
	xlab("") + ylab("") + theme(panel.background = element_blank(), axis.ticks = element_blank(), axis.text.x = element_blank(), axis.text.y = element_blank(), legend.position = "none") +
	scale_fill_gradient(low = "gray90", high = "gray10") 
t2.2

t.0 <- ggplot() + 
	geom_polygon(data=swiss, aes(x=.X, y=.Y, group = .ID, fill = slte.total.tp0), color="white") +
	geom_text(aes(x = 7.6, y = 46.9, label = "Berne"), color = "red") +
	xlab("") + ylab("") + theme(panel.background = element_blank(), axis.ticks = element_blank(), axis.text.x = element_blank(), axis.text.y = element_blank(), legend.position = "none") +
	scale_fill_gradient(low = "gray90", high = "gray10") 
t.0

t.1 <- ggplot() + 
	geom_polygon(data=swiss, aes(x=.X, y=.Y, group = .ID, fill = slte.total.tp1), color="white") +
	geom_text(aes(x = 7.6, y = 46.9, label = "Berne"), color = "red") +
	xlab("") + ylab("") + theme(panel.background = element_blank(), axis.ticks = element_blank(), axis.text.x = element_blank(), axis.text.y = element_blank(), legend.position = "none") +
	scale_fill_gradient(low = "gray90", high = "gray10") 
t.1

t.2 <- ggplot() + 
	geom_polygon(data=swiss, aes(x=.X, y=.Y, group = .ID, fill = slte.total.tp2), color="white") +
	geom_text(aes(x = 7.6, y = 46.9, label = "Berne"), color = "red") +
	xlab("") + ylab("") + theme(panel.background = element_blank(), axis.ticks = element_blank(), axis.text.x = element_blank(), axis.text.y = element_blank(), legend.position = "none") +
	scale_fill_gradient(low = "gray90", high = "gray10") 
t.2

# Combine the plots onto one figure
#pdf(file="Manuscript/cantons.pdf", family="Times")

grid.newpage()
pushViewport(viewport(layout = grid.layout(3,1)))

vplayout <- function(x, y) viewport(layout.pos.row = x, layout.pos.col = y)
print(t1.0, vp = vplayout(1, 1))
print(t1.1, vp = vplayout(2, 1))
print(t1.2, vp = vplayout(3, 1))

#dev.off()




#pdf(file="Manuscript/cantons.pdf", family="Times")

grid.newpage()
pushViewport(viewport(layout = grid.layout(3,3)))

vplayout <- function(x, y) viewport(layout.pos.row = x, layout.pos.col = y)
print(t1.0, vp = vplayout(1, 1))
print(t1.1, vp = vplayout(1, 2))
print(t1.2, vp = vplayout(1, 3))
print(t2.0, vp = vplayout(2, 1))
print(t2.1, vp = vplayout(2, 2))
print(t2.2, vp = vplayout(2, 3))
print(t.0, vp = vplayout(3, 1))
print(t.1, vp = vplayout(3, 2))
#grid.text(expression(paste("Average Total Effects, ", x[1])), x=.5, y=0.075, vp = vplayout(3, 2))
print(t.2, vp = vplayout(3, 3))

#dev.off()



### Good version, but with breaks
swiss$breaks <- cut(swiss$slte.total.tp1, 5)
s <- ggplot()
s <- s + geom_polygon(data=swiss, aes(x=.X, y=.Y, group = .ID, fill = breaks), color="white")
s <- s + xlab("") + ylab("") + theme(panel.background = element_blank(), axis.ticks = element_blank(), axis.text.x = element_blank(), axis.text.y = element_blank())
s <- s + scale_fill_brewer(palette = "Blues")
s


### Pretty good version
s <- ggplot()
s <- s + geom_polygon(data=swiss, aes(x=.X, y=.Y, group = .ID), color="white", fill="grey80")
s <- s + xlab("") + ylab("") + theme(axis.ticks = element_blank(), axis.text.x = element_blank(), axis.text.y = element_blank())
s








s <- ggplot(swiss, aes(x = .X, y = .Y)) + geom_polygon(aes(fill = slte.total.tp0))
s <- s + xlab("") + ylab("") + theme(axis.ticks = element_blank(), axis.text.x = element_blank(), axis.text.y = element_blank())
s



