*********************************************************************
*** Generate the original weights matrices for Gilardi and Wasserfallen (2016): project with Cody and Christopher
***
*** Created: 8-18-17
*** Modified:
***
*********************************************************************


clear
cd "C:\Users\williamslaro\Documents\Research\Projects\Spatial Methods\Diffusion\Survey\Replication\Gilardi-Wasserfallen-BJPS-2016-replication -- TLSL"

*use article/Figure_1/steuern.dta       
*tsset cantonid year

*sort year cantonid

/*********************************************************************/
/************* GENERATE THE WEIGHTS MATRICES  *************************/
/*********************************************************************/

* W^N: neighborhood (1 if cantons share a border)
spatwmat using "replication_archive/article/Table_3/W.dta", name(W_N)

qui foreach y of numlist 1991(1)2007 {
	mat W_N`y' = W_N
	svmat W_N`y'
	tempfile y`y'
	save `y`y'', replace 
	clear
}

use `y1991', clear
qui foreach y of numlist 1992(1)2007 {
	append using `y`y''
}

* Row total (for row-standardization)
tempvar rtotal
egen `rtotal' = rowtotal(W*)

qui foreach v of varlist _all {
	replace `v' = `v' / `rtotal'
	recode `v' (.=0)
}

cap drop _*
save "W/W_N.dta", replace

* W^C: Commuters: 1991-1997 (use 1990), 1998-2007 (use 2000) (original matrices are already row-standardized)
clear
spatwmat using "replication_archive/weights/commuter_1990_rs.dta", name(W_C_1990)
spatwmat using "replication_archive/weights/commuter_2000_rs.dta", name(W_C_2000)

qui foreach y of numlist 1991(1)1997 {
	mat W_C`y' = W_C_1990
	svmat W_C`y'
	tempfile y`y'
	save `y`y'', replace 
	clear
}

qui foreach y of numlist 1998(1)2007 {
	mat W_C`y' = W_C_2000
	svmat W_C`y'
	tempfile y`y'
	save `y`y'', replace 
	clear
}

use `y1991', clear
qui foreach y of numlist 1992(1)2007 {
	append using `y`y''
}

qui foreach v of varlist _all {
	recode `v' (.=0)
}

save "W/W_C.dta", replace
clear

* W^r: cantons not in the same conference: 1991-1997 (use 1990), 1998-2007 (use 2000)
spatwmat using "replication_archive/weights/not_same_conf_1990_x10_rs.dta", name(W_r_1990)
spatwmat using "replication_archive/weights/not_same_conf_2000_x10_rs.dta", name(W_r_2000)

qui foreach y of numlist 1991(1)1997 {
	mat W_r`y' = W_r_1990
	svmat W_r`y'
	tempfile y`y'
	save `y`y'', replace 
	clear
}

qui foreach y of numlist 1998(1)2007 {
	mat W_r`y' = W_r_2000
	svmat W_r`y'
	tempfile y`y'
	save `y`y'', replace 
	clear
}

use `y1991', clear
qui foreach y of numlist 1992(1)2007 {
	append using `y`y''
}

qui foreach v of varlist _all {
	recode `v' (.=0)
}

save "W/W_not.dta", replace
clear

* W^R: cantons in the same conference: 1991-1997 (use 1990), 1998-2007 (use 2000)
spatwmat using "replication_archive/weights/same_conf_1990_x10_rs.dta", name(W_R_1990)
spatwmat using "replication_archive/weights/same_conf_2000_x10_rs.dta", name(W_R_2000)

qui foreach y of numlist 1991(1)1997 {
	mat W_R`y' = W_R_1990
	svmat W_R`y'
	tempfile y`y'
	save `y`y'', replace 
	clear
}

qui foreach y of numlist 1998(1)2007 {
	mat W_R`y' = W_R_2000
	svmat W_R`y'
	tempfile y`y'
	save `y`y'', replace 
	clear
}

use `y1991', clear
qui foreach y of numlist 1992(1)2007 {
	append using `y`y''
}

qui foreach v of varlist _all {
	recode `v' (.=0)
}

save "W/W_R.dta", replace
clear

/*

/*********************************************************************/
/************* LOAD IN THE WEIGHTS MATRICES  *************************/
/*********************************************************************/
spatwmat using article/Table_3/W.dta, name(W_N)

*** Commuters for 1990: for 1990-1997
spatwmat using weights/commuter_1990_rs.dta, name(W_C_1990)

*** Commuters for 2000: for 1998-2007
spatwmat using weights/commuter_2000_rs.dta, name(W_C_2000)

*** Not in the same conference (1990)
spatwmat using weights/not_same_conf_1990_x10_rs.dta, name(W_r_1990)

*** Not in the same conference (2000)
spatwmat using weights/not_same_conf_2000_x10_rs.dta, name(W_r_2000)

*** In the same conference (1990)
spatwmat using weights/same_conf_1990_x10_rs.dta, name(W_R_1990)

*** In the same conference (2000)
spatwmat using weights/same_conf_2000_x10_rs.dta, name(W_R_2000)
*/
