*********************************************************************
*** Substantive effects for Gilardi and Wasserfallen (2016): project with Cody and Christopher
***
*** Created: 8-18-17
*** Modified:
***
*********************************************************************


clear
set matsize 1200
cd "C:\Users\williamslaro\Documents\Research\Projects\Spatial Methods\Diffusion\Survey\Replication\Gilardi-Wasserfallen-BJPS-2016-replication -- TLSL"

use "replication_archive/article/Figure_1/steuern.dta", clear
tsset cantonid year

/*********************************************************************/
/************* LOAD IN THE WEIGHTS MATRICES  *************************/
/*********************************************************************/

*** W_N: Neighbors
spatwmat using "replication_archive/article/Table_3/W.dta", name(W_N) s
spatwmat using "W/W_N.dta", name(W_Nfull) s

*** W_C: Commuters
spatwmat using "W/W_C.dta", name(W_Cfull)
 
* Commuters for 1990: for 1990-1997
spatwmat using "replication_archive/weights/commuter_1990_rs.dta", name(W_C_1990)

* Commuters for 2000: for 1998-2007
spatwmat using "replication_archive/weights/commuter_2000_rs.dta", name(W_C_2000)

*** W_r: Not in the same conference
spatwmat using "W/W_not.dta", name(W_rfull)

* Not in the same conference (1990)
spatwmat using "replication_archive/weights/not_same_conf_1990_x10_rs.dta", name(W_r_1990)

* Not in the same conference (2000)
spatwmat using "replication_archive/weights/not_same_conf_2000_x10_rs.dta", name(W_r_2000)

*** W_R: In the same conference
spatwmat using "W/W_R.dta", name(W_Rfull)

* In the same conference (1990)
spatwmat using "replication_archive/weights/same_conf_1990_x10_rs.dta", name(W_R_1990)

* In the same conference (2000)
spatwmat using "replication_archive/weights/same_conf_2000_x10_rs.dta", name(W_R_2000)

cap log close
*log using "Gilardi and Wasserfallen 2014--Substantive Effects.smcl", replace

/*********************************************************************/
/************* SUBSTANTIVE EFFECTS ***********************************/
/*********************************************************************/


******************************* Counterfactual (Model 5) ****************************************

xtpcse ks_150 sl_not_same_conf_x10_150 sl_same_conf_x10_150 schulden_capita_in10000 defizit_capita_in10000 arbl_prozent /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_* y1991 y1992 y1993 y1994/*
*/ y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007, c(psar1)
mat beta = e(b)

local theta1 = beta[1,1]
local theta2 = beta[1,2]
local beta = beta[1,4]

sum defizit_capita_in10000
local change_def = r(sd)

mat betavector1 = J(1,1,0)
mat betavector2 = J(1,1,`change_def'*`beta')
mat betavector3 = J(24,1,0)
mat betavector = betavector1\betavector2\betavector3

* TLSL #1
mat def1_1 = `theta1' * W_r_2000 * `change_def' * betavector
mat pd_def1 = def1_1
foreach n of numlist 2(1)5 {
	local nm1 = `n' - 1
	mat def1_`n' = `theta1' * W_r_2000 * (def1_`nm1')
	mat pd_def1 = pd_def1 + def1_`n'
}
	
* TLSL #2
mat def2_1 = `theta2' * W_R_2000 * `change_def' * betavector
mat pd_def2 = def2_1
foreach n of numlist 2(1)5 {
	local nm1 = `n' - 1
	mat def2_`n' = `theta2' * W_R_2000 * (def2_`nm1')
	mat pd_def2 = pd_def2 + def2_`n'
}

foreach n of numlist 1(1)5 {
	mat pd`n' = def1_`n' + def2_`n'
}

*** Establish canton IDs to match up with order of shapefile
matrix cantons = (25 \ 6 \ 12 \ 22 \ 18 \ 15 \ 14 \ 9 \ 26 \ 7 \ 19 \ 5 \ 4 \ 17 \ 2 \ 3 \ 16 \ 10 \ 1 \ 20 \ 21 \ 24 \ 23 \ 13 \ 8 \ 11)

mat slte_theta1_ = cantons,betavector,def1_1,def1_2,def1_3,def1_4
mat slte_theta2_ = cantons,betavector,def2_1,def2_2,def2_3,def2_4
mat slte_total_ = cantons,betavector,pd1,pd2,pd3,pd4

matrix rownames slte_theta1_ = Zurich Bern Luzern Uri Schwyz Obwalden Nidwalden Glarus Zug Fribourg Solothurn Basel-Stadt Basel-Landschaft Schaffhausen Appenzell-Ausserhoden Appenzell-Innerhoden StGallen Graubunden Aargau Thurgau Ticino Vaud Valais Neuchatel Geneva Jura
matrix rownames slte_theta2_ = Zurich Bern Luzern Uri Schwyz Obwalden Nidwalden Glarus Zug Fribourg Solothurn Basel-Stadt Basel-Landschaft Schaffhausen Appenzell-Ausserhoden Appenzell-Innerhoden StGallen Graubunden Aargau Thurgau Ticino Vaud Valais Neuchatel Geneva Jura
matrix rownames slte_total_ = Zurich Bern Luzern Uri Schwyz Obwalden Nidwalden Glarus Zug Fribourg Solothurn Basel-Stadt Basel-Landschaft Schaffhausen Appenzell-Ausserhoden Appenzell-Innerhoden StGallen Graubunden Aargau Thurgau Ticino Vaud Valais Neuchatel Geneva Jura

preserve
	clear
	svmat slte_theta1_
	rename slte_theta1_1 _ID
	
	foreach n of numlist 2(1)6 {
		local nm1 = `n' - 2
		rename slte_theta1_`n' slte_theta1_tp`nm1'
	}
	
	sort _ID
	tempfile theta1
	save `theta1', replace
restore

preserve
	clear
	svmat slte_theta2_
	rename slte_theta2_1 _ID
	
	foreach n of numlist 2(1)6 {
		local nm1 = `n' - 2
		rename slte_theta2_`n' slte_theta2_tp`nm1'
	}
	
	sort _ID
	tempfile theta2
	save `theta2', replace
restore

preserve
	clear
	svmat slte_total_
	rename slte_total_1 _ID
	
	foreach n of numlist 2(1)6 {
		local nm1 = `n' - 2
		rename slte_total_`n' slte_total_tp`nm1'
	}
	
	sort _ID
	tempfile total
	save `total', replace
restore

cap erase cantons.dta
cap erase cantonscoord.dta
shp2dta using "Switzerland\CHE_adm1", database(cantons) coordinates(cantonscoord) genid(id)

preserve
	use cantons, clear
	keep ID_1 NAME_1
	rename NAME_1 canton
	rename ID_1 _ID
	sort _ID
	tempfile names
	save `names', replace	
restore

preserve
	use cantonscoord, clear

	sort _ID
	merge _ID using `names'
	drop _merge
	
	sort _ID
	merge m:1 _ID using `theta1'
	drop _merge
	
	sort _ID
	merge m:1 _ID using `theta2'
	drop _merge

	sort _ID
	merge m:1 _ID using `total'
	drop _merge
	
	saveold "Figures\Swiss Cantons.dta", replace version(12)
restore



*** Spatial long-term effects with uncertainty

******************************* MODEL 1 ****************************************
xtpcse ks_150 spatlag_n_150 schulden_capita_in10000 defizit_capita_in10000 arbl_prozent  /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_* y1991 y1992 y1993 y1994/*
*/ y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007, c(psar1) 

*** Parameters and whatnot
local draws = 1000

mat beta = e(b)
mat vcm = e(V)

mat b = beta[1,1],beta[1,3],beta[1,4]
mat V = [vcm[1,1],vcm[3,1],vcm[4,1] \ vcm[1,3], vcm[3,3], vcm[4,3] \ vcm[1,4], vcm[3,4], vcm[4,4]]

*** Create the draws x draws matrix of simulated coefficients
preserve
	clear
	corr2data theta beta_def beta_un, n(`draws') means(b) cov(V)
	mkmat theta beta*, matrix(draws)
restore

*** Generate the standard deviations for both variables
sum defizit_capita_in10000
local change_def = r(sd)

sum arbl_prozent
local change_un = r(sd)

*** Create a draws x 6 empty matrix (3 columns for deficit, 3 columns for unemployment)
mat e = J(`draws',6,.)

*** Load the weights matrix in mata
mata: W = st_matrix("W_N")

*** Set up the loop
local d = 1
while `d' <= `draws' {
	local theta = draws[`d',1]

	*** Deficits
	local beta_def = draws[`d',2]
	
	mat def1 = `theta' * W_N * `change_def' * `beta_def'
	mat pd_def = def1
	foreach n of numlist 2(1)15 {
		local nm1 = `n' - 1
		mat def`n' = `theta' * W_N * (def`nm1')
		mat pd_def = pd_def + def`n'
	}
	
	mata: pd_def = st_matrix("pd_def")
	mata: ad_def = 1/rows(W)*trace(pd_def)
	mata: at_def = 1/rows(W)*sum(pd_def)
	mata: ai_def = 1/rows(W)*(sum(pd_def)-trace(pd_def))	

	mata: st_numscalar("ad_def", ad_def)
	mata: st_numscalar("at_def", at_def)
	mata: st_numscalar("ai_def", ai_def)		
	
	mat e[`d',1] = at_def
	mat e[`d',2] = ad_def
	mat e[`d',3] = ai_def
	
	*** Unemployment
	local beta_un = draws[`d',3]
	
	mat un1 = `theta' * W_N * `change_un' * `beta_un'
	mat pd_un = un1
	foreach n of numlist 2(1)15 {
		local nm1 = `n' - 1
		mat un`n' = `theta' * W_N * (un`nm1')
		mat pd_un = pd_un + un`n'
	}
	
	mata: pd_un = st_matrix("pd_un")
	mata: ad_un = 1/rows(W)*trace(pd_un)
	mata: at_un = 1/rows(W)*sum(pd_un)
	mata: ai_un = 1/rows(W)*(sum(pd_un)-trace(pd_un))	

	mata: st_numscalar("ad_un", ad_un)
	mata: st_numscalar("at_un", at_un)
	mata: st_numscalar("ai_un", ai_un)		
	
	mat e[`d',4] = at_un
	mat e[`d',5] = ad_un
	mat e[`d',6] = ai_un	
	
		*** Displays dots to let us know that Stata is still kicking.
	if mod(`d',10) == 0 {
		nois display "." _c
		if mod(`d',1000) == 0 {
			nois display ""
		}
	}	
	local d = `d' + 1
}

preserve
	clear
	svmat e

	qui foreach n of numlist 1(1)6 {
		sum e`n', meanonly
		local e`n'_mn = round(r(mean), .00001)
		
		_pctile e`n', perc(2.5 5.0 95.0 97.5)
		local e`n'_lo = round(r(r1), .00001)
		local e`n'_lo90 = round(r(r2), .00001)
		local e`n'_hi90 = round(r(r3), .00001)
		local e`n'_hi = round(r(r4), .00001)
		
		if `n' == 1 {
			nois di "Average total SLTE for 1-s.d. increase in deficit = " `e`n'_mn' ", [" `e`n'_lo' ", " `e`n'_hi' "]"
		}
		if `n' == 2 {
			nois di "Average direct SLTE for 1-s.d. increase in deficit = " `e`n'_mn' ", [" `e`n'_lo' ", " `e`n'_hi' "]"		
		}
		if `n' == 3 {
			nois di "Average indirect SLTE for 1-s.d. increase in deficit = " `e`n'_mn' ", [" `e`n'_lo' ", " `e`n'_hi' "]"
		}
		if `n' == 4 {
			nois di _newline(2) "Average total SLTE for 1-s.d. increase in unemployment = " `e`n'_mn' ", [" `e`n'_lo' ", " `e`n'_hi' "]"
		}
		if `n' == 5 {
			nois di "Average direct SLTE for 1-s.d. increase in unemployment = " `e`n'_mn' ", [" `e`n'_lo' ", " `e`n'_hi' "]"
		}
		if `n' == 6 {
			nois di "Average indirect SLTE for 1-s.d. increase in unemployment = " `e`n'_mn' ", [" `e`n'_lo' ", " `e`n'_hi' "]"
		}	
		nois di "90% confidence interval: [" `e`n'_lo90' ", " `e`n'_hi90' "]"		
		nois di _newline(1) 
	}
restore


******************************* MODEL 2 ****************************************
xtpcse ks_150 spatlag_c_150 schulden_capita_in10000 defizit_capita_in10000 arbl_prozent  /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_* y1991 y1992 y1993 y1994/*
*/ y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007, c(psar1)

*** Parameters and whatnot
mat beta = e(b)
mat vcm = e(V)

mat b = beta[1,1],beta[1,3],beta[1,4]
mat V = [vcm[1,1],vcm[3,1],vcm[4,1] \ vcm[1,3], vcm[3,3], vcm[4,3] \ vcm[1,4], vcm[3,4], vcm[4,4]]

*** Create the draws x draws matrix of simulated coefficients
preserve
	clear
	corr2data theta beta_def beta_un, n(`draws') means(b) cov(V)
	mkmat theta beta*, matrix(draws)
restore

*** Generate the standard deviations for both variables
sum defizit_capita_in10000
local change_def = r(sd)

sum arbl_prozent
local change_un = r(sd)

*** Create a draws x 6 empty matrix (3 columns for deficit, 3 columns for unemployment)
mat e = J(`draws',6,.)

*** Load the weights matrix in mata (commuter matrix for 2000)
mata: W = st_matrix("W_C_2000")

*** Set up the loop
local d = 1
while `d' <= `draws' {
	local theta = draws[`d',1]

	*** Deficits
	local beta_def = draws[`d',2]
	
	mat def1 = `theta' * W_C_2000 * `change_def' * `beta_def'
	mat pd_def = def1
	foreach n of numlist 2(1)15 {
		local nm1 = `n' - 1
		mat def`n' = `theta' * W_C_2000 * (def`nm1')
		mat pd_def = pd_def + def`n'
	}
	
	mata: pd_def = st_matrix("pd_def")
	mata: ad_def = 1/rows(W)*trace(pd_def)
	mata: at_def = 1/rows(W)*sum(pd_def)
	mata: ai_def = 1/rows(W)*(sum(pd_def)-trace(pd_def))	

	mata: st_numscalar("ad_def", ad_def)
	mata: st_numscalar("at_def", at_def)
	mata: st_numscalar("ai_def", ai_def)		
	
	mat e[`d',1] = at_def
	mat e[`d',2] = ad_def
	mat e[`d',3] = ai_def
	
	*** Unemployment
	local beta_un = draws[`d',3]
	
	mat un1 = `theta' * W_C_2000 * `change_un' * `beta_un'
	mat pd_un = un1
	foreach n of numlist 2(1)15 {
		local nm1 = `n' - 1
		mat un`n' = `theta' * W_C_2000 * (un`nm1')
		mat pd_un = pd_un + un`n'
	}
	
	mata: pd_un = st_matrix("pd_un")
	mata: ad_un = 1/rows(W)*trace(pd_un)
	mata: at_un = 1/rows(W)*sum(pd_un)
	mata: ai_un = 1/rows(W)*(sum(pd_un)-trace(pd_un))	

	mata: st_numscalar("ad_un", ad_un)
	mata: st_numscalar("at_un", at_un)
	mata: st_numscalar("ai_un", ai_un)		
	
	mat e[`d',4] = at_un
	mat e[`d',5] = ad_un
	mat e[`d',6] = ai_un	
	
		*** Displays dots to let us know that Stata is still kicking.
	if mod(`d',10) == 0 {
		nois display "." _c
		if mod(`d',1000) == 0 {
			nois display ""
		}
	}	
	local d = `d' + 1
}

preserve
	clear
	svmat e

	qui foreach n of numlist 1(1)6 {
		sum e`n', meanonly
		local e`n'_mn = round(r(mean), .00001)
		
		_pctile e`n', perc(2.5 5.0 95.0 97.5)
		local e`n'_lo = round(r(r1), .00001)
		local e`n'_lo90 = round(r(r2), .00001)
		local e`n'_hi90 = round(r(r3), .00001)
		local e`n'_hi = round(r(r4), .00001)
		
		if `n' == 1 {
			nois di "Average total SLTE for 1-s.d. increase in deficit = " `e`n'_mn' ", [" `e`n'_lo' ", " `e`n'_hi' "]"
		}
		if `n' == 2 {
			nois di "Average direct SLTE for 1-s.d. increase in deficit = " `e`n'_mn' ", [" `e`n'_lo' ", " `e`n'_hi' "]"		
		}
		if `n' == 3 {
			nois di "Average indirect SLTE for 1-s.d. increase in deficit = " `e`n'_mn' ", [" `e`n'_lo' ", " `e`n'_hi' "]"
		}
		if `n' == 4 {
			nois di _newline(2) "Average total SLTE for 1-s.d. increase in unemployment = " `e`n'_mn' ", [" `e`n'_lo' ", " `e`n'_hi' "]"
		}
		if `n' == 5 {
			nois di "Average direct SLTE for 1-s.d. increase in unemployment = " `e`n'_mn' ", [" `e`n'_lo' ", " `e`n'_hi' "]"
		}
		if `n' == 6 {
			nois di "Average indirect SLTE for 1-s.d. increase in unemployment = " `e`n'_mn' ", [" `e`n'_lo' ", " `e`n'_hi' "]"
		}	
		nois di "90% confidence interval: [" `e`n'_lo90' ", " `e`n'_hi90' "]"		
		nois di _newline(1) 
	}
restore

******************************* MODEL 3 ****************************************
xtpcse ks_150 sl_not_same_conf_x10_150 schulden_capita_in10000 defizit_capita_in10000 arbl_prozent  /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_* y1991 y1992 y1993 y1994/*
*/ y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007, c(psar1)

*** Parameters and whatnot
local draws = 1000

mat beta = e(b)
mat vcm = e(V)

mat b = beta[1,1],beta[1,3],beta[1,4]
mat V = [vcm[1,1],vcm[3,1],vcm[4,1] \ vcm[1,3], vcm[3,3], vcm[4,3] \ vcm[1,4], vcm[3,4], vcm[4,4]]

*** Create the draws x draws matrix of simulated coefficients
preserve
	clear
	corr2data theta beta_def beta_un, n(`draws') means(b) cov(V)
	mkmat theta beta*, matrix(draws)
restore

*** Generate the standard deviations for both variables
sum defizit_capita_in10000
local change_def = r(sd)

sum arbl_prozent
local change_un = r(sd)

*** Create a draws x 6 empty matrix (3 columns for deficit, 3 columns for unemployment)
mat e = J(`draws',6,.)

*** Load the weights matrix in mata (not in the same conference matrix for 2000)
mata: W = st_matrix("W_r_2000")

*** Set up the loop
local d = 1
while `d' <= `draws' {
	local theta = draws[`d',1]

	*** Deficits
	local beta_def = draws[`d',2]
	
	mat def1 = `theta' * W_r_2000 * `change_def' * `beta_def'
	mat pd_def = def1
	foreach n of numlist 2(1)15 {
		local nm1 = `n' - 1
		mat def`n' = `theta' * W_r_2000 * (def`nm1')
		mat pd_def = pd_def + def`n'
	}
	
	mata: pd_def = st_matrix("pd_def")
	mata: ad_def = 1/rows(W)*trace(pd_def)
	mata: at_def = 1/rows(W)*sum(pd_def)
	mata: ai_def = 1/rows(W)*(sum(pd_def)-trace(pd_def))	

	mata: st_numscalar("ad_def", ad_def)
	mata: st_numscalar("at_def", at_def)
	mata: st_numscalar("ai_def", ai_def)		
	
	mat e[`d',1] = at_def
	mat e[`d',2] = ad_def
	mat e[`d',3] = ai_def
	
	*** Unemployment
	local beta_un = draws[`d',3]
	
	mat un1 = `theta' * W_r_2000 * `change_un' * `beta_un'
	mat pd_un = un1
	foreach n of numlist 2(1)15 {
		local nm1 = `n' - 1
		mat un`n' = `theta' * W_r_2000 * (un`nm1')
		mat pd_un = pd_un + un`n'
	}
	
	mata: pd_un = st_matrix("pd_un")
	mata: ad_un = 1/rows(W)*trace(pd_un)
	mata: at_un = 1/rows(W)*sum(pd_un)
	mata: ai_un = 1/rows(W)*(sum(pd_un)-trace(pd_un))	

	mata: st_numscalar("ad_un", ad_un)
	mata: st_numscalar("at_un", at_un)
	mata: st_numscalar("ai_un", ai_un)		
	
	mat e[`d',4] = at_un
	mat e[`d',5] = ad_un
	mat e[`d',6] = ai_un	
	
		*** Displays dots to let us know that Stata is still kicking.
	if mod(`d',10) == 0 {
		nois display "." _c
		if mod(`d',1000) == 0 {
			nois display ""
		}
	}	
	local d = `d' + 1
}

preserve
	clear
	svmat e

	qui foreach n of numlist 1(1)6 {
		sum e`n', meanonly
		local e`n'_mn = round(r(mean), .00001)
		
		_pctile e`n', perc(2.5 5.0 95.0 97.5)
		local e`n'_lo = round(r(r1), .00001)
		local e`n'_lo90 = round(r(r2), .00001)
		local e`n'_hi90 = round(r(r3), .00001)
		local e`n'_hi = round(r(r4), .00001)
		
		if `n' == 1 {
			nois di "Average total SLTE for 1-s.d. increase in deficit = " `e`n'_mn' ", [" `e`n'_lo' ", " `e`n'_hi' "]"
		}
		if `n' == 2 {
			nois di "Average direct SLTE for 1-s.d. increase in deficit = " `e`n'_mn' ", [" `e`n'_lo' ", " `e`n'_hi' "]"		
		}
		if `n' == 3 {
			nois di "Average indirect SLTE for 1-s.d. increase in deficit = " `e`n'_mn' ", [" `e`n'_lo' ", " `e`n'_hi' "]"
		}
		if `n' == 4 {
			nois di _newline(2) "Average total SLTE for 1-s.d. increase in unemployment = " `e`n'_mn' ", [" `e`n'_lo' ", " `e`n'_hi' "]"
		}
		if `n' == 5 {
			nois di "Average direct SLTE for 1-s.d. increase in unemployment = " `e`n'_mn' ", [" `e`n'_lo' ", " `e`n'_hi' "]"
		}
		if `n' == 6 {
			nois di "Average indirect SLTE for 1-s.d. increase in unemployment = " `e`n'_mn' ", [" `e`n'_lo' ", " `e`n'_hi' "]"
		}	
		nois di "90% confidence interval: [" `e`n'_lo90' ", " `e`n'_hi90' "]"		
		nois di _newline(1) 
	}
restore

******************************* MODEL 4 ****************************************
xtpcse ks_150 sl_same_conf_x10_150 schulden_capita_in10000 defizit_capita_in10000 arbl_prozent  /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_* y1991 y1992 y1993 y1994/*
*/ y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007, c(psar1)

*** Parameters and whatnot
local draws = 1000

mat beta = e(b)
mat vcm = e(V)

mat b = beta[1,1],beta[1,3],beta[1,4]
mat V = [vcm[1,1],vcm[3,1],vcm[4,1] \ vcm[1,3], vcm[3,3], vcm[4,3] \ vcm[1,4], vcm[3,4], vcm[4,4]]

*** Create the draws x draws matrix of simulated coefficients
preserve
	clear
	corr2data theta beta_def beta_un, n(`draws') means(b) cov(V)
	mkmat theta beta*, matrix(draws)
restore

*** Generate the standard deviations for both variables
sum defizit_capita_in10000
local change_def = r(sd)

sum arbl_prozent
local change_un = r(sd)

*** Create a draws x 6 empty matrix (3 columns for deficit, 3 columns for unemployment)
mat e = J(`draws',6,.)

*** Load the weights matrix in mata (in the same conference matrix for 2000)
mata: W = st_matrix("W_R_2000")

*** Set up the loop
local d = 1
while `d' <= `draws' {
	local theta = draws[`d',1]

	*** Deficits
	local beta_def = draws[`d',2]
	
	mat def1 = `theta' * W_R_2000 * `change_def' * `beta_def'
	mat pd_def = def1
	foreach n of numlist 2(1)15 {
		local nm1 = `n' - 1
		mat def`n' = `theta' * W_R_2000 * (def`nm1')
		mat pd_def = pd_def + def`n'
	}
	
	mata: pd_def = st_matrix("pd_def")
	mata: ad_def = 1/rows(W)*trace(pd_def)
	mata: at_def = 1/rows(W)*sum(pd_def)
	mata: ai_def = 1/rows(W)*(sum(pd_def)-trace(pd_def))	

	mata: st_numscalar("ad_def", ad_def)
	mata: st_numscalar("at_def", at_def)
	mata: st_numscalar("ai_def", ai_def)		
	
	mat e[`d',1] = at_def
	mat e[`d',2] = ad_def
	mat e[`d',3] = ai_def
	
	*** Unemployment
	local beta_un = draws[`d',3]
	
	mat un1 = `theta' * W_R_2000 * `change_un' * `beta_un'
	mat pd_un = un1
	foreach n of numlist 2(1)15 {
		local nm1 = `n' - 1
		mat un`n' = `theta' * W_R_2000 * (un`nm1')
		mat pd_un = pd_un + un`n'
	}
	
	mata: pd_un = st_matrix("pd_un")
	mata: ad_un = 1/rows(W)*trace(pd_un)
	mata: at_un = 1/rows(W)*sum(pd_un)
	mata: ai_un = 1/rows(W)*(sum(pd_un)-trace(pd_un))	

	mata: st_numscalar("ad_un", ad_un)
	mata: st_numscalar("at_un", at_un)
	mata: st_numscalar("ai_un", ai_un)		
	
	mat e[`d',4] = at_un
	mat e[`d',5] = ad_un
	mat e[`d',6] = ai_un	
	
		*** Displays dots to let us know that Stata is still kicking.
	if mod(`d',10) == 0 {
		nois display "." _c
		if mod(`d',1000) == 0 {
			nois display ""
		}
	}	
	local d = `d' + 1
}

preserve
	clear
	svmat e

	qui foreach n of numlist 1(1)6 {
		sum e`n', meanonly
		local e`n'_mn = round(r(mean), .00001)
		
		_pctile e`n', perc(2.5 5.0 95.0 97.5)
		local e`n'_lo = round(r(r1), .00001)
		local e`n'_lo90 = round(r(r2), .00001)
		local e`n'_hi90 = round(r(r3), .00001)
		local e`n'_hi = round(r(r4), .00001)
		
		if `n' == 1 {
			nois di "Average total SLTE for 1-s.d. increase in deficit = " `e`n'_mn' ", [" `e`n'_lo' ", " `e`n'_hi' "]"
		}
		if `n' == 2 {
			nois di "Average direct SLTE for 1-s.d. increase in deficit = " `e`n'_mn' ", [" `e`n'_lo' ", " `e`n'_hi' "]"		
		}
		if `n' == 3 {
			nois di "Average indirect SLTE for 1-s.d. increase in deficit = " `e`n'_mn' ", [" `e`n'_lo' ", " `e`n'_hi' "]"
		}
		if `n' == 4 {
			nois di _newline(2) "Average total SLTE for 1-s.d. increase in unemployment = " `e`n'_mn' ", [" `e`n'_lo' ", " `e`n'_hi' "]"
		}
		if `n' == 5 {
			nois di "Average direct SLTE for 1-s.d. increase in unemployment = " `e`n'_mn' ", [" `e`n'_lo' ", " `e`n'_hi' "]"
		}
		if `n' == 6 {
			nois di "Average indirect SLTE for 1-s.d. increase in unemployment = " `e`n'_mn' ", [" `e`n'_lo' ", " `e`n'_hi' "]"
		}	
		nois di "90% confidence interval: [" `e`n'_lo90' ", " `e`n'_hi90' "]"		
		nois di _newline(1) 
	}
restore


******************************* MODEL 5 ****************************************
xtpcse ks_150 sl_not_same_conf_x10_150 sl_same_conf_x10_150 schulden_capita_in10000 defizit_capita_in10000 arbl_prozent /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_* y1991 y1992 y1993 y1994/*
*/ y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007, c(psar1)

*** Parameters and whatnot
local draws = 1000

mat beta = e(b)
mat vcm = e(V)

mat b = beta[1,1],beta[1,2],beta[1,4],beta[1,5]
mat V = [vcm[1,1],vcm[2,1],vcm[4,1],vcm[5,1] \ /*
*/		 vcm[1,2],vcm[2,2],vcm[4,2],vcm[5,2] \ /* 
*/		 vcm[1,4],vcm[2,4],vcm[4,4],vcm[5,4] \ /*
*/		 vcm[1,5],vcm[2,5],vcm[4,5],vcm[5,5]]

*** Create the draws x draws matrix of simulated coefficients
preserve
	clear
	corr2data theta1 theta2 beta_def beta_un, n(`draws') means(b) cov(V)
	mkmat theta* beta*, matrix(draws)
restore

*** Generate the standard deviations for both variables
sum defizit_capita_in10000
local change_def = r(sd)

sum arbl_prozent
local change_un = r(sd)

*** Create a draws x 6 empty matrix (3 columns for deficit, 3 columns for unemployment)
mat e = J(`draws',6,.)

*** Load the weights matrix in mata (in the same conference matrix for 2000)
mata: W = st_matrix("W_R_2000")

*** Set up the loop
local d = 1
while `d' <= `draws' {
	local theta1 = draws[`d',1]
	local theta2 = draws[`d',2]
	
	*** Deficits
	local beta_def = draws[`d',3]
	
	* TLSL #1
	mat def1 = `theta1' * W_r_2000 * `change_def' * `beta_def'
	mat pd_def1 = def1
	foreach n of numlist 2(1)15 {
		local nm1 = `n' - 1
		mat def`n' = `theta1' * W_r_2000 * (def`nm1')
		mat pd_def1 = pd_def1 + def`n'
	}
	
	* TLSL #2
	mat def1 = `theta2' * W_R_2000 * `change_def' * `beta_def'
	mat pd_def2 = def1
	foreach n of numlist 2(1)15 {
		local nm1 = `n' - 1
		mat def`n' = `theta2' * W_R_2000 * (def`nm1')
		mat pd_def2 = pd_def2 + def`n'
	}
	
	mat pd_def = pd_def1 + pd_def2
	
	mata: pd_def = st_matrix("pd_def")
	mata: ad_def = 1/rows(W)*trace(pd_def)
	mata: at_def = 1/rows(W)*sum(pd_def)
	mata: ai_def = 1/rows(W)*(sum(pd_def)-trace(pd_def))	

	mata: st_numscalar("ad_def", ad_def)
	mata: st_numscalar("at_def", at_def)
	mata: st_numscalar("ai_def", ai_def)		
	
	mat e[`d',1] = at_def
	mat e[`d',2] = ad_def
	mat e[`d',3] = ai_def
	
	*** Unemployment
	local beta_un = draws[`d',4]
	
	* TLSL #1
	mat un1 = `theta1' * W_r_2000 * `change_un' * `beta_un'
	mat pd_un1 = un1
	foreach n of numlist 2(1)15 {
		local nm1 = `n' - 1
		mat un`n' = `theta1' * W_r_2000 * (un`nm1')
		mat pd_un1 = pd_un1 + un`n'
	}
	
	* TLSL #2
	mat un1 = `theta2' * W_R_2000 * `change_un' * `beta_un'
	mat pd_un2 = un1
	foreach n of numlist 2(1)15 {
		local nm1 = `n' - 1
		mat un`n' = `theta2' * W_R_2000 * (un`nm1')
		mat pd_un2 = pd_un2 + un`n'
	}
	
	mat pd_un = pd_un1 + pd_un2
	
	mata: pd_un = st_matrix("pd_un")
	mata: ad_un = 1/rows(W)*trace(pd_un)
	mata: at_un = 1/rows(W)*sum(pd_un)
	mata: ai_un = 1/rows(W)*(sum(pd_un)-trace(pd_un))	

	mata: st_numscalar("ad_un", ad_un)
	mata: st_numscalar("at_un", at_un)
	mata: st_numscalar("ai_un", ai_un)		
	
	mat e[`d',4] = at_un
	mat e[`d',5] = ad_un
	mat e[`d',6] = ai_un	
	
		*** Displays dots to let us know that Stata is still kicking.
	if mod(`d',10) == 0 {
		nois display "." _c
		if mod(`d',1000) == 0 {
			nois display ""
		}
	}	
	local d = `d' + 1
}

preserve
	clear
	svmat e

	qui foreach n of numlist 1(1)6 {
		sum e`n', meanonly
		local e`n'_mn = round(r(mean), .00001)
		
		_pctile e`n', perc(2.5 5.0 95.0 97.5)
		local e`n'_lo = round(r(r1), .00001)
		local e`n'_lo90 = round(r(r2), .00001)
		local e`n'_hi90 = round(r(r3), .00001)
		local e`n'_hi = round(r(r4), .00001)
		
		if `n' == 1 {
			nois di "Average total SLTE for 1-s.d. increase in deficit = " `e`n'_mn' ", [" `e`n'_lo' ", " `e`n'_hi' "]"
		}
		if `n' == 2 {
			nois di "Average direct SLTE for 1-s.d. increase in deficit = " `e`n'_mn' ", [" `e`n'_lo' ", " `e`n'_hi' "]"		
		}
		if `n' == 3 {
			nois di "Average indirect SLTE for 1-s.d. increase in deficit = " `e`n'_mn' ", [" `e`n'_lo' ", " `e`n'_hi' "]"
		}
		if `n' == 4 {
			nois di _newline(2) "Average total SLTE for 1-s.d. increase in unemployment = " `e`n'_mn' ", [" `e`n'_lo' ", " `e`n'_hi' "]"
		}
		if `n' == 5 {
			nois di "Average direct SLTE for 1-s.d. increase in unemployment = " `e`n'_mn' ", [" `e`n'_lo' ", " `e`n'_hi' "]"
		}
		if `n' == 6 {
			nois di "Average indirect SLTE for 1-s.d. increase in unemployment = " `e`n'_mn' ", [" `e`n'_lo' ", " `e`n'_hi' "]"
		}	
		nois di "90% confidence interval: [" `e`n'_lo90' ", " `e`n'_hi90' "]"		
		nois di _newline(1) 
	}
restore


log close





/* Illustration!

*mat W = (0, .5, .5 \ .5, 0, 0 \ .5, 0, 0)
mat W = (0, 1, 1 \ 1, 0, 0 \ 1, 0, 0)
scalar beta = 1
scalar theta = 0.25
scalar changex = 1

*** Uniform change for all observations: 1*\beta
mat pd_slte_tp1 = theta * W * changex * beta
mat effects = pd_slte_tp1
foreach n of numlist 2(1)10 {
	local nm1 = `n' - 1
	mat pd_slte_tp`n' = theta * W * (pd_slte_tp`nm1')
	mat effects = effects + pd_slte_tp`n'
}

mat list effects
mat C = J(colsof(effects),1,1)
mat total = effects * C
mat list total


*** My attempt at calculating the SLTE with mata: this doesn't work!
mata: 
W = (0, 1, 1 \ 1, 0, 0 \ 1, 0, 0)
test = W:^10
theta = 0.25
beta = 1
changex = 1
pd1 = theta * W:^1 * changex * beta
pd6 = theta * W:^6 * changex * beta
pd10 = theta * W:^10 * changex * beta
pd1
pd6
pd10
end:

*/


*** Spatial long-term effects
* Model 1
xtpcse ks_150 spatlag_n_150 schulden_capita_in10000 defizit_capita_in10000 arbl_prozent  /*
*/ ausg_capita_in10000 ktant_capita_in10000 l.pop_ej_log l.svp_ej l.fdp_ej l.cvp_ej l.left_ej /*
*/ l.fimi_svp_aj l.fimi_fdp_aj l.fimi_cvp_aj l.fimi_left_aj _icantonid_* y1991 y1992 y1993 y1994/*
*/ y1995 y1996 y1997 y1998 y1999 y2000 y2001 y2002 y2003 y2004 y2005 y2006 y2007, c(psar1) 
mat beta = e(b)

sum defizit_capita_in10000
local change = r(sd)

local theta = beta[1,1]
local defbeta = beta[1,3]
local unbeta = beta[1,4]

*mat betavector = J(26,1,`defbeta')

* 1-standard deviation increase in deficit for #1 observation
mat betavector1 = J(1,1,`change'*`defbeta')
mat betavector2 = J(25,1,0)
mat betavector = betavector1\betavector2

/* This produces an NxN matrix of changes in y (not what we want)
mat def_tp1 = `theta' * W_N * `defbeta'
mat list def_tp1
*/

mat def_tp1 = `theta' * W_N * betavector
mat list def_tp1

mat def_tp2 = `theta' * W_N * `theta' * W_N * betavector
mat def_tp3 = `theta' * W_N * `theta' * W_N * `theta' * W_N * betavector
mat def_tp4 = `theta' * W_N * `theta' * W_N * `theta' * W_N * `theta' * W_N * betavector
mat def_tp5 = `theta' * W_N * `theta' * W_N * `theta' * W_N * `theta' * W_N * `theta' * W_N * betavector

mat def_tp2_v2 = `theta' * W_N * def_tp1
mat def_tp3_v2 = `theta' * W_N * def_tp2_v2
mat def_tp4_v2 = `theta' * W_N * def_tp3_v2
mat def_tp5_v2 = `theta' * W_N * def_tp4_v2

* First five order of effects together
mat effects = betavector,def_tp1,def_tp2,def_tp3,def_tp4, def_tp5
mat list effects

/* Old code:
mat def_tp1 = `theta' * W_N * betavector
mat list def_tp1

mat def_tp2 = `theta' * W_N * `theta' * W_N * `defbeta'
mat def_tp3 = `theta' * W_N * `theta' * W_N * `theta' * W_N * `defbeta'
mat def_tp4 = `theta' * W_N * `theta' * W_N * `theta' * W_N * `theta' * W_N * `defbeta'
*/

/* Old code
mat def_tp1 = `theta' * W_N * `defbeta'
mat def_tp2 = `theta' * W_N * `theta' * W_N * `defbeta'
mat def_tp3 = `theta' * W_N * `theta' * W_N * `theta' * W_N * `defbeta'
mat def_tp4 = `theta' * W_N * `theta' * W_N * `theta' * W_N * `theta' * W_N * `defbeta'
*/

/* Full NxN matrix:

mat def_tp1 = `theta' * W_Nfull * `defbeta'
mat def_tp2 = `theta' * W_Nfull * def_tp1
mat def_tp3 = `theta' * W_Nfull * def_tp2
mat def_tp4 = `theta' * W_Nfull * def_tp3
*/

*mat list def_tp1

