# Load libraries

library(spdep)
library(lattice)


# Load data

d <- read.csv("steuern.csv")
W <- as.matrix(read.csv("W_neighbors.csv", header=FALSE))


# Moran's I

w.n <- mat2listw(W)
listw.n <- nb2listw(neighbours=w.n$neighbours, glist= w.n$weights, style="W")

moran.h <- moran.test(d$ks_200[d$year==2007], listw= listw.n)
moran.est.h <- round(moran.h$estimate[1], 3)
moran.pval.h <- round(moran.h$p.value, 3)

moran.l <- moran.test(d$ks_50[d$year==2007], listw= listw.n)
moran.est.l <- round(moran.l$estimate[1], 3)
moran.pval.l <- round(moran.l$p.value, 3)


# Maps 

con <- url("http://gadm.org/data/rda/CHE_adm1.RData")
mapid <- c(27, 6, 13, 23, 19, 16, 15, 9, 26, 7, 20, 5, 4, 18, 2, 3, 17, 10, 1, 21, 22, 25, 24, 14, 8, 11)
col  <-  rev(heat.colors(26))
cc <- gray(seq(1, 0.3, length.out=26))


ks.h <- rep(NA, 27)

for(i in 1:26){
	j <- mapid[i]
	ks.h[j] <- d$ks_200[d$year==2007][i]
	}

gadm$ks.h <- ks.h


ks.l <- rep(NA, 27)

for(i in 1:26){
	j <- mapid[i]
	ks.l[j] <- d$ks_50[d$year==2007][i]
	}

gadm$ks.l <- ks.l


#pdf(file='map200col.pdf', paper="special", width=7, height=4.5)
spplot(gadm, "ks.h", col.regions=col, main=list(label=paste("200k, 2007", "\nMoran's I =", moran.est.h, ", p-value =", moran.pval.h), font=1))
#dev.off()

#pdf(file='map200bw.pdf', paper="special", width=7, height=4.5)
spplot(gadm, "ks.h", col.regions=cc, main=list(label=paste("200k, 2007", "\nMoran's I =", moran.est.h, ", p-value =", moran.pval.h), font=1))
#dev.off()

#pdf(file='map50col.pdf', paper="special", width=7, height=4.5)
spplot(gadm, "ks.l", col.regions=col, main=list(label=paste("50k, 2007", "\nMoran's I =", moran.est.l, ", p-value =", moran.pval.l), font=1))
#dev.off()

#pdf(file='map50bw.pdf', paper="special", width=7, height=4.5)
spplot(gadm, "ks.l", col.regions=cc, main=list(label=paste("50k, 2007", "\nMoran's I =", moran.est.l, ", p-value =", moran.pval.l), font=1))
#dev.off()


